@@ -4,14 +4,11 @@ in the scenario.
 """
 from typing import cast
 
-from behave.runner import Context
-from behave import register_type, then, given, when  # pylint: disable=no-name-in-module
-
 from grizzly.types import RequestDirection, RequestMethod
-
-from .._helpers import add_request_task, get_task_client, is_template
-from ...context import GrizzlyContext
-from ...tasks import (
+from grizzly.types.behave import Context, register_type, then, given, when
+from grizzly.steps._helpers import add_request_task, get_task_client, is_template
+from grizzly.context import GrizzlyContext
+from grizzly.tasks import (
     LogMessageTask,
     WaitTask,
     TransformerTask,
