@@ -13,6 +13,40 @@ a previous response or fetching additional test data from a different endpoint (
 It is possible to implement custom tasks, the only requirement is that they inherit `grizzly.tasks.GrizzlyTask`. To get them to be executed by `grizzly`,
 a step implementation is also needed.
 
+Boilerplate example of a custom task:
+
+```python
+from typing import Any, cast
+
+from grizzly.context import GrizzlyContext
+from grizzly.tasks import GrizzlyTask, grizzlytask
+from grizzly.scenarios import GrizzlyScenario
+from grizzly.types.behave import Context, then
+
+
+class TestTask(GrizzlyTask):
+    def __call__(self) -> grizzlytask:
+        @grizzlytask
+        def task(parent: GrizzlyScenario) -> Any:
+            print(f'{self.__class__.__name__}::task called')
+
+        @task.on_start
+        def on_start() -> None:
+            print(f'{self.__class__.__name__}::on_start called')
+
+        @task.on_stop
+        def on_stop() -> None:
+            print(f'{self.__class__.__name__}::on_stop called')
+
+        return task
+
+
+@then(u'run `TestTask`')
+def step_run_testtask(context: Context) -> None:
+    grizzly = cast(GrizzlyContext, context.grizzly)
+    grizzly.scenario.tasks.add(TestTask())
+```
+
 There are examples of this in the {@link framework.example}.
 '''
 from abc import ABC, ABCMeta, abstractmethod
@@ -24,8 +58,49 @@ from grizzly_extras.transformer import TransformerContentType
 
 if TYPE_CHECKING:  # pragma: no cover
     from grizzly.types import GrizzlyResponse
-    from ..scenarios import GrizzlyScenario
-    from ..context import GrizzlyContextScenario
+    from grizzly.scenarios import GrizzlyScenario
+    from grizzly.context import GrizzlyContextScenario
+
+GrizzlyTaskType = Callable[['GrizzlyScenario'], Any]
+GrizzlyTaskOnType = Optional[Callable[[], None]]
+
+
+class grizzlytask:
+    __name__ = 'grizzlytask'
+
+    _on_start: Optional['OnGrizzlyTask'] = None
+    _on_stop: Optional['OnGrizzlyTask'] = None
+
+    class OnGrizzlyTask:
+        _on_func: Optional[GrizzlyTaskOnType] = None
+
+        def __init__(self, on_func: GrizzlyTaskOnType) -> None:
+            self._on_func = on_func
+
+        def __call__(self) -> None:
+            if self._on_func is not None:
+                self._on_func()
+
+    def __init__(self, task: GrizzlyTaskType, doc: Optional[str] = None) -> None:
+        self._task = task
+
+        if doc is None and task is not None:
+            self.__doc__ = doc
+
+    def __call__(self, parent: 'GrizzlyScenario') -> Any:
+        return self._task(parent)
+
+    def on_start(self, on_start: GrizzlyTaskOnType = None) -> None:
+        if self._on_start is None:
+            self._on_start = self.OnGrizzlyTask(on_start)
+        else:
+            self._on_start()
+
+    def on_stop(self, on_stop: GrizzlyTaskOnType = None) -> None:
+        if self._on_stop is None:
+            self._on_stop = self.OnGrizzlyTask(on_stop)
+        else:
+            self._on_stop()
 
 
 class GrizzlyTask(ABC):
@@ -34,6 +109,7 @@ class GrizzlyTask(ABC):
     _context_root: str
 
     scenario: 'GrizzlyContextScenario'
+    step: str
 
     def __init__(self, scenario: Optional['GrizzlyContextScenario'] = None) -> None:
         self._context_root = environ.get('GRIZZLY_CONTEXT_ROOT', '.')
@@ -41,7 +117,7 @@ class GrizzlyTask(ABC):
             self.scenario = scenario
 
     @abstractmethod
-    def __call__(self) -> Callable[['GrizzlyScenario'], Any]:
+    def __call__(self) -> grizzlytask:
         raise NotImplementedError(f'{self.__class__.__name__} has not been implemented')
 
     def get_templates(self) -> List[str]:
@@ -136,6 +212,7 @@ from .timer import TimerTask
 from .task_wait import TaskWaitTask
 from .conditional import ConditionalTask
 from .loop import LoopTask
+from .set_variable import SetVariableTask
 
 
 __all__ = [
@@ -152,4 +229,5 @@ __all__ = [
     'TaskWaitTask',
     'ConditionalTask',
     'LoopTask',
+    'SetVariableTask',
 ]
