@@ -19,7 +19,7 @@ import logging
 import traceback
 
 from abc import abstractmethod
-from typing import Dict, Generator, Type, List, Any, Optional, Callable, cast
+from typing import Dict, Generator, Type, List, Any, Optional, cast, final
 from contextlib import contextmanager
 from time import perf_counter as time
 from urllib.parse import urlparse, unquote
@@ -32,12 +32,11 @@ from grizzly_extras.transformer import TransformerContentType
 from grizzly_extras.arguments import split_value, parse_arguments
 
 from grizzly.types import RequestType, RequestDirection, GrizzlyResponse
-
-from ...context import GrizzlyContext, GrizzlyContextScenario
-from ...scenarios import GrizzlyScenario
-from ...testdata.utils import resolve_variable
-from ...users.base import RequestLogger
-from .. import GrizzlyMetaRequestTask, template
+from grizzly.context import GrizzlyContext, GrizzlyContextScenario
+from grizzly.scenarios import GrizzlyScenario
+from grizzly.testdata.utils import resolve_variable
+from grizzly.users.base import RequestLogger
+from grizzly.tasks import GrizzlyMetaRequestTask, template, grizzlytask
 
 
 # see https://github.com/python/mypy/issues/5374
@@ -129,11 +128,30 @@ class ClientTask(GrizzlyMetaRequestTask):
         self.log_dir = Path(context_root) / 'logs'
         self.log_dir.mkdir(parents=True, exist_ok=True)
 
-    def __call__(self) -> Callable[[GrizzlyScenario], GrizzlyResponse]:
-        if self.direction == RequestDirection.FROM:
-            return self.get
-        else:
-            return self.put
+    def on_start(self) -> None:
+        pass
+
+    def on_stop(self) -> None:
+        pass
+
+    @final
+    def __call__(self) -> grizzlytask:
+        @grizzlytask
+        def task(parent: 'GrizzlyScenario') -> GrizzlyResponse:
+            if self.direction == RequestDirection.FROM:
+                return self.get(parent)
+            else:
+                return self.put(parent)
+
+        @task.on_start
+        def on_start() -> None:
+            return self.on_start()
+
+        @task.on_stop
+        def on_stop() -> None:
+            return self.on_stop()
+
+        return task
 
     def execute(self, parent: GrizzlyScenario) -> GrizzlyResponse:
         return self.get(parent)
@@ -147,7 +165,7 @@ class ClientTask(GrizzlyMetaRequestTask):
         raise NotImplementedError(f'{self.__class__.__name__} has not implemented PUT')
 
     @contextmanager
-    def action(self, parent: GrizzlyScenario, action: Optional[str] = None, supress: bool = False) -> Generator[Dict[str, Any], None, None]:
+    def action(self, parent: GrizzlyScenario, action: Optional[str] = None, suppress: bool = False) -> Generator[Dict[str, Any], None, None]:
         exception: Optional[Exception] = None
         response_length = 0
         start_time = time()
@@ -169,7 +187,10 @@ class ClientTask(GrizzlyMetaRequestTask):
             response_time = int((time() - start_time) * 1000)
             response_length = meta.get('response_length', None) or 0
 
-            if not supress or exception is not None:
+            if exception is None:
+                exception = meta.get('exception', None)
+
+            if not suppress or exception is not None:
                 parent.user.environment.events.request.fire(
                     request_type=RequestType.CLIENT_TASK(),
                     name=name,
@@ -179,7 +200,7 @@ class ClientTask(GrizzlyMetaRequestTask):
                     exception=exception,
                 )
 
-            if exception is not None or parent.user._scenario.context.get('log_all_requests', False) or meta.get('response', {}).get('status', 200) != 200:
+            if exception is not None or parent.user._scenario.context.get('log_all_requests', False):
                 log_name = RequestLogger.normalize(name)
                 log_date = datetime.now()
                 log_file = self.log_dir / f'{log_name}.{log_date.strftime("%Y%m%dT%H%M%S%f")}.log'
