@@ -83,11 +83,11 @@ from gevent import sleep as gsleep
 from grizzly_extras.async_message import AsyncMessageContext, AsyncMessageResponse, AsyncMessageRequest
 
 from grizzly.types import GrizzlyResponse, RequestDirection, RequestType
+from grizzly.context import GrizzlyContextScenario
+from grizzly.scenarios import GrizzlyScenario
+from grizzly.testdata.utils import resolve_variable
 
 from . import client, ClientTask, logger
-from ...context import GrizzlyContextScenario
-from ...scenarios import GrizzlyScenario
-from ...testdata.utils import resolve_variable
 
 
 try:
@@ -273,7 +273,7 @@ class MessageQueueClientTask(ClientTask):
             client_id = id(parent)
             worker = self._worker.get(client_id, None)
             if worker is None:
-                with self.action(parent, supress=True) as meta:
+                with self.action(parent, suppress=True) as meta:
                     self.connect(client_id, client, meta)
                     worker = self._worker.get(client_id, None)
                     parent.logger.debug(f'connected to worker {worker} at {hostname()}')
