@@ -93,9 +93,8 @@ from grizzly_extras.arguments import split_value, parse_arguments, get_unsupport
 from grizzly_extras.transformer import TransformerContentType
 
 from grizzly.types import RequestType, bool_type
-
-from ...context import GrizzlyContext
-from ..utils import resolve_variable
+from grizzly.context import GrizzlyContext
+from grizzly.testdata.utils import resolve_variable
 from . import AtomicVariable
 
 
@@ -457,9 +456,6 @@ class AtomicServiceBus(AtomicVariable[str]):
 
             return payload
 
-    def __setitem__(self, variable: str, value: Optional[str]) -> None:
-        pass
-
     def __delitem__(self, variable: str) -> None:
         with self.semaphore():
             try:
