@@ -2,11 +2,11 @@ from typing import Optional, Generator, Dict, cast
 from time import perf_counter as time, sleep
 from contextlib import contextmanager
 
-from ...transformer import transformer, TransformerError, TransformerContentType
-from ...arguments import parse_arguments, get_unsupported_arguments
+from grizzly_extras.transformer import transformer, TransformerError, TransformerContentType
+from grizzly_extras.arguments import parse_arguments, get_unsupported_arguments
 
 
-from .. import (
+from grizzly_extras.async_message import (
     AsyncMessageRequest,
     AsyncMessageResponse,
     AsyncMessageError,
@@ -45,6 +45,7 @@ class AsyncMessageQueueHandler(AsyncMessageHandler):
         if self.qmgr is not None:
             self.logger.debug('closing queue manager connection')
             self.qmgr.disconnect()
+            self.qmgr = None
 
     @contextmanager
     def queue_context(self, endpoint: str, browsing: Optional[bool] = False) -> Generator[pymqi.Queue, None, None]:
@@ -64,6 +65,14 @@ class AsyncMessageQueueHandler(AsyncMessageHandler):
         finally:
             queue.close()
 
+    @register(handlers, 'DISC')
+    def disconnect(self, request: AsyncMessageRequest) -> AsyncMessageResponse:
+        self.close()
+
+        return {
+            'message': 'disconnected',
+        }
+
     @register(handlers, 'CONN')
     def connect(self, request: AsyncMessageRequest) -> AsyncMessageResponse:
         if self.qmgr is not None:
