@@ -17,8 +17,6 @@ from getpass import getuser
 
 from locust.clients import ResponseContextManager
 from locust.contrib.fasthttp import FastResponse, FastRequest
-from locust.env import Environment
-from locust.runners import Runner
 from geventhttpclient.header import Headers
 from geventhttpclient.response import HTTPSocketPoolResponse
 from _pytest.tmpdir import TempPathFactory
@@ -27,17 +25,18 @@ from paramiko.transport import Transport
 from paramiko.channel import Channel
 from paramiko.sftp import BaseSFTP
 from paramiko.sftp_client import SFTPClient
-from behave.runner import Context as BehaveContext, Runner as BehaveRunner
-from behave.model import Scenario, Step, Background, Feature
 from behave.configuration import Configuration
 from behave.step_registry import registry as step_registry
+from behave.model import Background
+from behave.runner import Runner as BehaveRunner
 from requests.models import CaseInsensitiveDict, Response, PreparedRequest
 
 from grizzly.types import GrizzlyResponseContextManager, RequestMethod
+from grizzly.types.behave import Context as BehaveContext, Scenario, Step, Feature
 from grizzly.tasks import RequestTask
 from grizzly.testdata.variables import destroy_variables
-
 from grizzly.context import GrizzlyContext, GrizzlyContextScenario
+from grizzly.types.locust import Environment, LocustRunner
 
 from .helpers import TestUser, TestScenario, RequestSilentFailureEvent
 from .helpers import onerror, run_command
@@ -57,6 +56,7 @@ __all__ = [
     'RequestTaskFixture',
     'GrizzlyFixture',
     'NoopZmqFixture',
+    'MockerFixture',
 ]
 
 
@@ -80,7 +80,7 @@ class LocustFixture:
     _tmp_path_factory: TempPathFactory
 
     env: Environment
-    runner: Runner
+    runner: LocustRunner
 
     def __init__(self, tmp_path_factory: TempPathFactory) -> None:
         self._tmp_path_factory = tmp_path_factory
@@ -220,8 +220,6 @@ class ParamikoFixture:
             _get,
         )
 
-        print('patched paramiko')
-
 
 class BehaveFixture:
     _locust_fixture: LocustFixture
@@ -291,14 +289,15 @@ class RequestTaskFixture:
     context_root: str
     relative_path: str
     request: RequestTask
+    test_context: Path
 
     def __init__(self, tmp_path_factory: TempPathFactory) -> None:
         self._tmp_path_factory = tmp_path_factory
 
     def __enter__(self) -> 'RequestTaskFixture':
-        test_context = self._tmp_path_factory.mktemp('example_payload') / 'requests'
-        test_context.mkdir()
-        request_file = test_context / 'payload.j2.json'
+        self.test_context = self._tmp_path_factory.mktemp('example_payload') / 'requests'
+        self.test_context.mkdir()
+        request_file = self.test_context / 'payload.j2.json'
         request_file.touch()
         request_file.write_text(REQUEST_TASK_TEMPLATE_CONTENTS)
         request_path = path.dirname(str(request_file))
@@ -340,6 +339,10 @@ class GrizzlyFixture:
         self.request_task = request_task
         self.behave = behave_fixture.context
 
+    @property
+    def test_context(self) -> Path:
+        return self.request_task.test_context
+
     def __enter__(self) -> 'GrizzlyFixture':
         environ['GRIZZLY_CONTEXT_ROOT'] = path.abspath(path.join(self.request_task.context_root, '..'))
         self.grizzly = GrizzlyContext()
@@ -777,8 +780,7 @@ def step_start_webserver(context: Context, port: int) -> None:
         with open(self._root / 'features' / 'steps' / 'steps.py', 'w') as fd:
             fd.write('from importlib import import_module\n')
             fd.write('from typing import cast, Callable, Any\n\n')
-            fd.write('from behave import then\n')
-            fd.write('from behave.runner import Context\n')
+            fd.write('from grizzly.types.behave import Context, then\n')
             fd.write('from grizzly.locust import on_master, on_worker, on_local\n')
             fd.write('from grizzly.context import GrizzlyContext, GrizzlyContextScenario\n')
             fd.write('from grizzly.tasks import GrizzlyTask\n')
@@ -1022,11 +1024,10 @@ def step_start_webserver(context: Context, port: int) -> None:
         # add after_feature hook, always write all of 'em
         with open(environment_file, 'w') as fd:
             fd.write('from typing import Any, Tuple, Dict, cast\n\n')
-            fd.write('from behave.runner import Context\n')
-            fd.write('from behave.model import Feature\n')
+            fd.write('from grizzly.types.behave import Context, Feature\n')
             fd.write('from grizzly.context import GrizzlyContext\n')
             fd.write((
-                'from grizzly.environment import before_feature as grizzly_before_feature, '
+                'from grizzly.behave import before_feature as grizzly_before_feature, '
                 'after_feature as grizzly_after_feature, before_scenario, after_scenario, before_step\n\n'
             ))
 
